<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:oai="http://www.openarchives.org/OAI/2.0/" xmlns:datetime="http://exslt.org/dates-and-times"
                xmlns:dri="http://www.driver-repository.eu/namespace/dri"
                xmlns:md="http://www.pangaea.de/MetaData"
                xmlns:oaa="http://namespace.openaire.eu/oaa" xmlns:oaf="http://namespace.openaire.eu/oaf"
                xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:dnet="eu.dnetlib.data.transform.xml.AbstractDNetXsltFunctions"
                xmlns:stringUtils="org.apache.commons.lang.StringUtils"
                version="1.0"
                exclude-result-prefixes="xsl dnet oaa fn stringUtils datetime">
	<xsl:param name="namespacePrefix"/>
	<xsl:param name="dataSourceId"/>
	<xsl:param name="parentDatasourceId"/>
	<xsl:param name="dataprovider_name"/>
	<xsl:param name="dataprovider_id"/>
	<xsl:template match="/">

		<xsl:variable name="identifier_datacite">
			<xsl:value-of select="oai:record/oai:header/dri:objIdentifier"/>
		</xsl:variable>

		<xsl:variable name="dataset_identifier">
			<xsl:value-of
					select="stringUtils:substringAfter(//md:citation/md:URI,'doi:')"/>
		</xsl:variable>
		<xsl:variable name="openaire_dataset_identifier">
			<xsl:value-of
					select="concat($namespacePrefix,'::', dnet:md5($dataset_identifier))"/>
		</xsl:variable>

		<xsl:variable name="parentURI">
			<xsl:value-of select="//md:citation/md:parentURI"/>
		</xsl:variable>

		<xsl:call-template name="CreateRecord">
			<xsl:with-param name="openaire_dataset_identifier" select="$openaire_dataset_identifier"/>
			<xsl:with-param name="dataset_identifier" select="$dataset_identifier"/>
			<xsl:with-param name="parent_uri" select="$parentURI"/>
		</xsl:call-template>


	</xsl:template>
	<xsl:template name="CreateRecord">
		<xsl:param name="openaire_dataset_identifier"/>
		<xsl:param name="dataset_identifier"/>
		<xsl:param name="parent_uri"/>
		<xsl:variable name="parentUri">
			<xsl:value-of select="//md:citation/md:parentURI"/>
		</xsl:variable>
		<oai:record>
			<oai:header>
				<xsl:choose>
					<xsl:when test="string-length($parentUri) = 0">
						<xsl:choose>
							<xsl:when test="//md:citation/md:supplementTo">
								<dri:objIdentifier>
									<xsl:value-of select="$openaire_dataset_identifier"/>
								</dri:objIdentifier>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<dri:objIdentifier>
							<xsl:value-of select="$openaire_dataset_identifier"/>
						</dri:objIdentifier>
					</xsl:otherwise>
				</xsl:choose>
				<dri:recordIdentifier>
					<xsl:value-of select="$dataset_identifier"/>
				</dri:recordIdentifier>
				<dri:dateOfCollection>
					<xsl:value-of select="datetime:dateTime()"/>
				</dri:dateOfCollection>
				<dri:repositoryId>
					<xsl:value-of select="$dataprovider_id"/>
				</dri:repositoryId>
				<oaf:datasourceprefix>
					<xsl:value-of select="$namespacePrefix"/>
				</oaf:datasourceprefix>
			</oai:header>
			<oai:metadata>
				<resource
						xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
						xsi:schemaLocation="http://datacite.org/schema/kernel-3 http://schema.datacite.org/meta/kernel-3/metadata.xsd"
						xmlns="http://datacite.org/schema/kernel-3">
					<identifier identifierType="DOI">
						<xsl:value-of
								select="$dataset_identifier"/>
					</identifier>
					<creators>
						<xsl:for-each select="//md:citation/md:author">
							<creator>
								<creatorName>
									<xsl:value-of select="concat(./md:firstName, ' ', ./md:lastName)"/>
								</creatorName>
								<nameIdentifier schemeURI="http://www.pangaea.de"
								                nameIdentifierScheme="PANGAEA">
									<xsl:value-of select="./@id"/>
								</nameIdentifier>

							</creator>
						</xsl:for-each>
					</creators>
					<titles>
						<xsl:for-each select="//md:citation/md:title">
							<title xml:lang="en-us">
								<xsl:value-of select="."/>
							</title>
						</xsl:for-each>
					</titles>
					<publisher>PANGAEA</publisher>
					<publicationYear>
						<xsl:value-of select="//md:citation/md:year"/>
					</publicationYear>
					<resourceType resourceTypeGeneral="Dataset"/>
					<xsl:variable name="description">
						<xsl:value-of select="//md:citation/md:abstract"/>
					</xsl:variable>
					<xsl:if test="$description">
						<descriptions>
							<description descriptionType="Abstract">
								<xsl:value-of select="$description"/>
							</description>
						</descriptions>
					</xsl:if>
					<rights>info:eu-repo/semantics/openAccess</rights>
					<contributors>
						<contributor contributorType="Funder">
							<contributorName>European Commission</contributorName>
							<nameIdentifier nameIdentifierScheme="info">
								<xsl:value-of
										select="//oaf:projectid"/>
							</nameIdentifier>
						</contributor>
					</contributors>
				</resource>
				<xsl:variable name="journalName">
					<xsl:value-of select="//*[local-name() ='journal']/@name"/>
				</xsl:variable>
				<xsl:variable name="journalISSN">
					<xsl:value-of select="//*[local-name() ='journal']/@issn"/>
				</xsl:variable>
				<xsl:variable name="journalDSId">
					<xsl:value-of select="//*[local-name() ='journal']/@datasourceid"/>
				</xsl:variable>

				<xsl:choose>
					<xsl:when test="string-length($journalISSN) &gt; 0">
						<oaf:journal issn="{$journalISSN}" eissn="">
							<xsl:value-of select="$journalName"/>
						</oaf:journal>
						<oaf:hostedBy>
							<xsl:attribute name="id">
								<xsl:value-of select="$journalDSId"/>
							</xsl:attribute>
							<xsl:attribute name="name">
								<xsl:value-of select="$journalName"/>
							</xsl:attribute>
						</oaf:hostedBy>
					</xsl:when>
					<xsl:otherwise>
						<oaf:hostedBy
								id="openaire____::1256f046-bf1f-4afc-8b47-d0b147148b18"
								name="Unknown Repository"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:for-each select="//md:citation/md:supplementTo/@id">
					<xsl:variable name="publicationID">
						<xsl:value-of select="."/>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="string-length($publicationID) &gt; 0">
							<oaf:relatedPublication>
								<xsl:attribute name="id">
									<xsl:value-of
											select="concat($namespacePrefix,'::', dnet:md5($publicationID))"/>
								</xsl:attribute>
							</oaf:relatedPublication>
						</xsl:when>
					</xsl:choose>
				</xsl:for-each>

				<xsl:choose>
					<xsl:when test="string-length($parent_uri) &gt; 0">
						<xsl:variable name="dataset_relate_ID">
							<xsl:value-of select="stringUtils:substringAfter($parent_uri,'doi:')"/>
						</xsl:variable>
						<xsl:choose>
							<xsl:when test="string-length($dataset_relate_ID) &gt; 0">
								<oaf:relatedDataSet>
									<xsl:attribute name="id">
										<xsl:value-of
												select="concat($namespacePrefix,'::', dnet:md5($dataset_relate_ID))"/>
									</xsl:attribute>
								</oaf:relatedDataSet>
							</xsl:when>
						</xsl:choose>

					</xsl:when>
				</xsl:choose>

				<oaf:about>
					<oaf:datainfo>
						<oaf:inferred>false</oaf:inferred>
						<oaf:deletedbyinference>false</oaf:deletedbyinference>
						<oaf:trust>0.9</oaf:trust>
						<oaf:inferenceprovenance/>
						<oaf:provenanceaction classid="sysimport:crosswalk:datasetarchive"
						                      classname="sysimport:crosswalk:datasetarchive"
						                      schemeid="dnet:provenanceActions"
						                      schemename="dnet:provenanceActions"/>
					</oaf:datainfo>
				</oaf:about>
			</oai:metadata>
		</oai:record>
	</xsl:template>
</xsl:stylesheet>
