<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:dr="http://www.driver-repository.eu/namespace/dr"
                xmlns:oai="http://www.openarchives.org/OAI/2.0/" xmlns:datetime="http://exslt.org/dates-and-times"
                xmlns:dri="http://www.driver-repository.eu/namespace/dri" xmlns:md="http://www.pangaea.de/MetaData"
                xmlns:oaa="http://namespace.openaire.eu/oaa" xmlns:oaf="http://namespace.openaire.eu/oaf"
                xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:dnet="eu.dnetlib.data.transform.xml.AbstractDNetXsltFunctions"
                xmlns:stringUtils="org.apache.commons.lang.StringUtils"
                version="1.0"
                exclude-result-prefixes="xsl dnet oaa fn stringUtils datetime">

	<xsl:param name="namespacePrefix"/>
	<xsl:param name="dataprovider_id"/>
	<xsl:param name="parentDatasourceId"/>
	<xsl:param name="dataprovider_name"/>

	<xsl:template match="/">
		<xsl:variable name="identifier">
			<xsl:value-of
					select="stringUtils:substringAfter(//md:citation/md:URI,'doi:')"/>
		</xsl:variable>
		<xsl:variable name="identifier_datacite">
			<xsl:value-of select="oai:record/oai:header/dri:objIdentifier"/>
		</xsl:variable>
		<publications>
			<xsl:for-each select="//md:citation/md:supplementTo">
				<xsl:variable name="pub_identifier">
					<xsl:value-of select="./@id"/>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="string-length($pub_identifier)">
						<xsl:call-template name="GeneratePublication">
							<xsl:with-param name="pub_identifier" select="$pub_identifier"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</publications>
	</xsl:template>
	<xsl:template name="GeneratePublication">
		<xsl:param name="pub_identifier"/>
		<publication>
			<oai:record>
				<oai:header>
					<dri:objIdentifier>
						<xsl:value-of
								select="concat($namespacePrefix,'::', dnet:md5($pub_identifier))"/>
					</dri:objIdentifier>
					<dri:recordIdentifier>
						<xsl:value-of select="$pub_identifier"/>
					</dri:recordIdentifier>
					<dri:dateOfCollection>
						<xsl:value-of select="datetime:dateTime()"/>
					</dri:dateOfCollection>
					<dri:repositoryId>
						<xsl:value-of select="$dataprovider_id"/>
					</dri:repositoryId>
					<oaf:datasourceprefix>
						<xsl:value-of select="$namespacePrefix"/>
					</oaf:datasourceprefix>
				</oai:header>
				<oai:metadata>
					<dc:identifier>
						<xsl:value-of select="$pub_identifier"/>
					</dc:identifier>
					<xsl:variable name="publicationDOI">
						<xsl:value-of select="./md:URI"/>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="string-length($publicationDOI) &gt; 0">
							<dc:identifier>
								<xsl:value-of select="$publicationDOI"/>
							</dc:identifier>
						</xsl:when>
					</xsl:choose>

					<dc:title>
						<xsl:value-of select=".//md:title"/>
					</dc:title>
					<xsl:for-each select=".//md:author">
						<dc:creator>
							<xsl:value-of select="concat(./md:lastName,' ', md:firstName)"/>
						</dc:creator>
					</xsl:for-each>
					<dc:source>
						<xsl:value-of select="./md:source"/>
					</dc:source>
					<dr:CobjCategory>0000</dr:CobjCategory>
					<dc:language>und</dc:language>
					<oaf:journal>
						<xsl:value-of select="./md:source"/>
					</oaf:journal>
					<oaf:accessrights>UNKNOWN</oaf:accessrights>
					<xsl:variable name="projectId">
						<xsl:value-of select="normalize-space(//*[local-name() ='projectid'])"/>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="string-length(substring-after($projectId, 'info:eu-repo/grantAgreement/EC/FP7/')) > 0">
							<oaf:projectid>
								<xsl:value-of
										select="concat('corda_______::', substring-after($projectId, 'info:eu-repo/grantAgreement/EC/FP7/'))"/>
							</oaf:projectid>
						</xsl:when>
						<xsl:when test="string-length(substring-after($projectId, 'info:eu-repo/grantAgreement/EC/H2020/')) > 0">
							<oaf:projectid>
								<xsl:value-of
										select="concat('corda_______::', substring-after($projectId, 'info:eu-repo/grantAgreement/EC/H2020/'))"/>
							</oaf:projectid>
						</xsl:when>
						<xsl:otherwise>
							<oaf:projectid><xsl:value-of select="$projectId"/></oaf:projectid>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:variable name="journalName">
						<xsl:value-of select="//*[local-name() ='journal']/@name"/>
					</xsl:variable>
					<xsl:variable name="journalISSN">
						<xsl:value-of select="//*[local-name() ='journal']/@issn"/>
					</xsl:variable>
					<xsl:variable name="journalDSId">
						<xsl:value-of select="//*[local-name() ='journal']/@datasourceid"/>
					</xsl:variable>

					<xsl:choose>
						<xsl:when test="string-length($journalISSN) &gt; 0">
							<oaf:journal issn="{$journalISSN}" eissn="">
								<xsl:value-of select="$journalName"/>
							</oaf:journal>
							<oaf:hostedBy>
								<xsl:attribute name="id">
									<xsl:value-of
											select="$journalDSId"/>
								</xsl:attribute>
								<xsl:attribute name="name">
									<xsl:value-of
											select="$journalName"/>
								</xsl:attribute>
							</oaf:hostedBy>
						</xsl:when>
						<xsl:otherwise>
							<oaf:hostedBy
									id="openaire____::1256f046-bf1f-4afc-8b47-d0b147148b18" name="Unknown Repository"/>
						</xsl:otherwise>
					</xsl:choose>


					<oaf:collectedFrom>
						<xsl:attribute name="id">
							<xsl:value-of select="$parentDatasourceId"/>
						</xsl:attribute>
						<xsl:attribute name="name">
							<xsl:value-of select="$dataprovider_name"/>
						</xsl:attribute>
					</oaf:collectedFrom>
					<oaf:about>
						<oaf:datainfo>
							<oaf:inferred>false</oaf:inferred>
							<oaf:deletedbyinference>false</oaf:deletedbyinference>
							<oaf:trust>0.9</oaf:trust>
							<oaf:inferenceprovenance/>
							<oaf:provenanceaction classid="sysimport:crosswalk:datasetarchive"
							                      classname="sysimport:crosswalk:datasetarchive" schemeid="dnet:provenanceActions"
							                      schemename="dnet:provenanceActions"/>
						</oaf:datainfo>
					</oaf:about>
				</oai:metadata>
			</oai:record>
		</publication>
	</xsl:template>
</xsl:stylesheet>
