<NODE name="SET_INFO" isStart="true" type="SetProviderInfo">
	<DESCRIPTION>Set information about current provider</DESCRIPTION>
	<PARAMETERS>
		<PARAM required="true" type="string" name="providerId" managedBy="system">$params.("dataprovider:id")$</PARAM>
		<PARAM required="true" type="string" name="providerName" managedBy="system">$params.("dataprovider:name")$</PARAM>
		<PARAM required="true" type="string" name="api" managedBy="system">$params.("dataprovider:interface")$</PARAM>
	</PARAMETERS>
	<ARCS>
		<ARC to="selectIncrementalTransformation"/>
    </ARCS>
</NODE>

<NODE name="selectIncrementalTransformation" type="IncrementalTransformation">
    <DESCRIPTION>Decide REFRESH/INCREMENTAL transformation</DESCRIPTION>
    <PARAMETERS>
        <PARAM required="true" type="string" name="operationType" managedBy="user" function="validValues(['REFRESH','INCREMENTAL'])"></PARAM>
    </PARAMETERS>
    <ARCS>
        <ARC to="obtainParams"/>
    </ARCS>
</NODE>

<NODE name="obtainParams" type="ObtainOpenaireDataSourceParams">
    <DESCRIPTION>Obtain params on datasource</DESCRIPTION>
    <PARAMETERS>
        <PARAM required="true" type="string" name="providerId" managedBy="system">$params.("dataprovider:id")$</PARAM>
    </PARAMETERS>
    <ARCS>
        <ARC to="fetchOriginals"/>
    </ARCS>
</NODE>

<NODE name="fetchOriginals" type="FetchMDStoreRecords">
	<DESCRIPTION>Fetch records from MDStore</DESCRIPTION>
	<PARAMETERS>
		<PARAM required="true" type="string" name="mdId" managedBy="system" category="MDSTORE_ID">$params.("orig_id")$</PARAM>
		<PARAM required="true" type="string" name="mdFormat" managedBy="system">$params.("orig_format")$</PARAM>
		<PARAM required="true" type="string" name="eprParam" managedBy="system">orig_epr</PARAM>
	</PARAMETERS>
	<ARCS>
		<ARC to="transform"/>
	</ARCS>
</NODE>

<NODE name="transform" type="Transform">
	<DESCRIPTION>Transform original records in DB rows</DESCRIPTION>
	<PARAMETERS>
		<PARAM required="true" type="string" name="ruleId" managedBy="user" category="TRANSFORMATION_RULE_ID" function="listProfiles('TransformationRuleDSResourceType', '//TITLE')"></PARAM>
		<PARAM required="true" type="string" name="inputEprParam" managedBy="system">orig_epr</PARAM>
		<PARAM required="true" type="string" name="outputEprParam" managedBy="system">packed_row_epr</PARAM>
	</PARAMETERS>
	<ARCS>
		<ARC to="cleanRows"/>
	</ARCS>
</NODE>

<NODE name="cleanRows" type="Clean">
	<DESCRIPTION>Clean DB rows values according to defined vocabularies</DESCRIPTION>
	<PARAMETERS>
		<PARAM required="true" type="string" name="ruleId" managedBy="user" category="CLEANER_RULE_ID" function="listProfiles('CleanerDSResourceType', '//CLEANER_NAME')"></PARAM>
		<PARAM required="true" type="string" name="inputEprParam" managedBy="system">packed_row_epr</PARAM>
		<PARAM required="true" type="string" name="outputEprParam" managedBy="system">cleaned_row_epr</PARAM>
	</PARAMETERS>
	<ARCS>
		<ARC to="filterManaged"/>
	</ARCS>
</NODE>

<NODE name="filterManaged" type="FilterManagedDatasources">
    <DESCRIPTION>Filter DB rows according to the managed flag state</DESCRIPTION>
    <PARAMETERS>
        <PARAM managedBy="system" name="inputEprParam" required="true" type="string">cleaned_row_epr</PARAM>
        <PARAM managedBy="system" name="outputEprParam" required="true" type="string">filtered_row_epr</PARAM>
    </PARAMETERS>
    <ARCS>
        <ARC to="storeRowRecords"/>
    </ARCS>
</NODE>

<NODE name="storeRowRecords" type="StoreMDStoreRecords">
	<DESCRIPTION>Store mdtore records</DESCRIPTION>
	<PARAMETERS>
		<PARAM required="true" type="string" name="mdId" managedBy="system" category="MDSTORE_ID">$params.("row_id")$</PARAM>
		<PARAM required="true" type="string" name="storingType" managedBy="system">REFRESH</PARAM>
		<PARAM required="true" type="string" name="eprParam" managedBy="system">filtered_row_epr</PARAM>
	</PARAMETERS>
	<ARCS>
		<ARC to="UPDATE_INFO"/>
	</ARCS>
</NODE>

 <NODE name="UPDATE_INFO" type="MDStoreToApiExtraField">
	<DESCRIPTION>Update datasouce API extra fields</DESCRIPTION>
	<PARAMETERS>
		<PARAM required="true" type="string" name="mdId" managedBy="system">$params.("row_id")$</PARAM>
		<PARAM required="true" type="string" name="datasourceId" managedBy="system">$params.("dataprovider:id")$</PARAM>
		<PARAM required="true" type="string" name="datasourceInterface" managedBy="system">$params.("dataprovider:interface")$</PARAM>
		<PARAM required="true" type="string" name="extraFieldForTotal" managedBy="system">last_aggregation_total</PARAM>
		<PARAM required="true" type="string" name="extraFieldForDate" managedBy="system">last_aggregation_date</PARAM>
		<PARAM required="true" type="string" name="extraFieldForMdId" managedBy="system">last_aggregation_mdId</PARAM>
	</PARAMETERS>
	<ARCS>
		<ARC to="success"/>
	</ARCS>
</NODE>
